function R=nan_histo2(Y)
//  calculates histogram of each column
// Calling Sequence
// R=nan_histo2(Y)         
// 	R : is a struct with th fields 
//       R.X : are the bin-values 
//       R.H : is the frequency of occurence of value X 
//  	R.N  : are the number of valid (not %nan) samples 
// Description
// more histogram-based results can be obtained by hist2res2  
// Examples
// x= [ 9 9 9 9 2 2 3 3 4 5 9 ]';
// R=nan_histo2(x);
// H=nan_hist2res(R);
// Bibliography
//  C.E. Shannon and W. Weaver "The mathematical theory of communication" University of Illinois Press, Urbana 1949 (reprint 1963).
// See also
// nan_hist2res
// nan_histo
// nan_histo3
// nan_histo4
// Authors
//	Copyright (C) 1996-2002,2008 by Alois Schloegl a.schloegl@ieee.org
// H. Nahrstaedt - 2010

//	$Id: histo2.m 5090 2008-06-05 08:12:04Z schloegl $
//	Copyright (C) 1996-2002,2008 by Alois Schloegl <a.schloegl@ieee.org>	
//    	This is part of the TSA-toolbox 
//	http://hci.tugraz.at/~schloegl/matlab/tsa/
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 [nargout,nargin]=argn(0);
if (nargin == 0),
 error('At least 1 parameter required');
end;

[yr,yc] = size(Y);

if yr==1,
        // Makes sure there is a second row
        // Sort does not support the DIM-argument, therefore,
        // this function would not work correctly with this software
        // Once this is fixed, this part can be removed. 
        Y = [Y; %nan+ones(Y)];  
end;

sY  = mtlb_sort(Y);
N   = sum(~isnan(Y),1);
[ix,iy] = find(diff(sY,1)>0);
nn0 = 0;
warning('off');

for k=1:yc,
	tmp    = [ix(iy==k), N(k)]';
        nn1    = length(tmp);
        
        H(1:nn1,k) = diff([0; tmp]);
       	X(1:nn1,k) = sY(tmp,k);

        if nn1<nn0;
                H(1+nn1:nn0,k) = %nan;
                X(1+nn1:nn0,k) = %nan;
        elseif nn1>nn0,
                H(1+nn0:nn1,1:k-1) = mtlb_repmat(%nan,nn1-nn0,k-1);
                X(1+nn0:nn1,1:k-1) = mtlb_repmat(%nan,nn1-nn0,k-1);
                nn0 = nn1;
        end;
end;

R.datatype = 'HISTOGRAM';
R.H = H;
R.X = X;
R.N = sumskipnan(R.H,1);


endfunction
