function Q=nan_trimmean(Y,p,DIM)
//  calculates the trimmed mean by removing the upper and lower
// (p/2)% samples.
// Calling Sequence
//  Q = nan_trimmean(Y,p)
//  Q = nan_trimmean(Y,p,DIM)
//  Description
//  trimmean calculates the trimmed mean by removing the upper and lower
// (p/2)% samples. Missing values (encoded as NaN) are also removed. 
//     returns the trimmean along dimension DIM of sample array Y.
// See also
// nan_percentile
// nan_quantile
// Authors
//  Copyright (C) 2009,2010 by Alois Schloegl a.schloegl@ieee.org
//  H. Nahrstaedt - 2010

//	$Id$
//	Copyright (C) 2009,2010 by Alois Schloegl <a.schloegl@ieee.org>	
//       This function is part of the NaN-toolbox
//       http://biosig-consulting.com/matlab/NaN/

//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; If not, see <http://www.gnu.org/licenses/>.
 [nargout,nargin]=argn(0);
if nargin<3,
        DIM = [];
end;
if isempty(DIM),
        DIM = find(size(Y)>1,1);
        if isempty(DIM), DIM = 1; end;
end;

if nargin<2,
	error("At least two argument neeeded!");
        
else
	q1 = p/200; 
	q2 = 1-p/200; 

	sz = size(Y);
	if DIM>length(sz),
	        sz = [sz,ones(1,DIM-length(sz))];
	end;

	D1 = prod(sz(1:DIM-1));
	D3 = prod(sz(DIM+1:length(sz)));
	Q  = mtlb_repmat(%nan,[sz(1:DIM-1),1,sz(DIM+1:length(sz))]);
	for k = 0:D1-1,
		for l = 0:D3-1,
		        xi = k + l * D1*sz(DIM) + 1 ;
			xo = k + l * D1*length(1) + 1; //length(q)?
		        t  = Y(xi:D1:xi+D1*sz(DIM)-1);
		        t  = mtlb_sort(t(~isnan(t)));
		        N  = length(t); 
		        ix = ((1:N) < N*q2) & ((1:N) > N*q1);
		        f  = nan_mean(t(ix));
			Q(xo:D1:xo + D1*length(1) - 1) = f;//length(q)?
		end;
	end;
end;

endfunction
