// Copyright (C) 2010 - H. Nahrstaedt
//
// assert_close --
// Returns 1 if the two real matrices computed and expected are close,
// i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
// computed, expected : the two matrices to compare
// epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
// Returns 1 if the two real matrices computed and expected are equal.
// Arguments
// computed, expected : the two matrices to compare
// epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if ( and ( computed==expected ) ) then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

A=[1,2,10;7,7.1,7.01];

computed = nan_std(A);
expected = st_deviation(A,'r');

assert_close ( computed , expected , %eps );

computed = nan_std(A,[],2);
expected = st_deviation(A,'c');

assert_close ( computed , expected , %eps );

computed = nan_std(A(:));
expected = st_deviation(A);

assert_close ( computed , expected , %eps );


A=[1 1 %nan];
computed = nan_std(A);
expected = 0;

assert_close ( computed , expected , %eps );

A=[1 1 %nan];
computed = nan_std(A');
expected = 0;

assert_close ( computed , expected , %eps );

computed = isnan(nan_std(0));
expected = %T;

assert_equal ( computed , expected );