// Copyright (C) 2010 - H. Nahrstaedt
//
// assert_close --
// Returns 1 if the two real matrices computed and expected are close,
// i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
// computed, expected : the two matrices to compare
// epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
// Returns 1 if the two real matrices computed and expected are equal.
// Arguments
// computed, expected : the two matrices to compare
// epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if ( and ( computed==expected ) ) then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

A=[1,2;3,4];

computed = sumskipnan(A);
expected = sum(A,1);
assert_close ( computed , expected , %eps );

computed = sumskipnan(A(:));
expected = sum(A);
assert_close ( computed , expected , %eps );

I=uint8([2 95 103;254 9 0]);
computed = sumskipnan(I(:));
expected = sum(I,"double");
assert_close ( computed , expected ,  %eps );


B=[%t %t %f %f];
computed = sumskipnan(B);
expected = sum(B);
assert_close ( computed , expected , %eps );

x=[1 1 %nan];
computed = sumskipnan(x);
expected = 2;
assert_close ( computed , expected , %eps );

x=[1 1 %nan];
computed = sumskipnan(x');
expected = 2;
assert_close ( computed , expected , %eps );


x=[1 %i %nan];
computed = sumskipnan(x);
expected = 1+%i;
assert_close ( computed , expected , %eps );

x=[%i %i %nan];
computed = sumskipnan(x);
expected = 2*%i;
assert_close ( computed , expected , %eps );


x=[1 1 %nan];
[tmp, computed] = sumskipnan(x);
expected = 2;
assert_close ( computed , expected , %eps );

x=[-1 1 %nan];
[tmp, tmp, computed] = sumskipnan(x);
expected = 2;
assert_close ( computed , expected , %eps );